monitor_species: Simulated monitoring performance for predicted invaders

View source: R/monitor_species.R

monitor_speciesR Documentation

Simulated monitoring performance for predicted invaders

Description

Evaluates the probability of :

  1. Detecting at least one invasion within n given species, under ranked monitoring, i.e. the highest-probability n species, vs a random selection.

  2. Given an invasion, detecting it within the n species, under ranked monitoring, i.e. the highest-probability n species, vs a random selection.

Usage

monitor_species(pred_out, plot = FALSE, max_n = 25)

Arguments

pred_out

Output from predict_invasible().

plot

Logical. If TRUE, returns ggplot objects.

max_n

Integer. Highest n value to be plotted (n=25 as default).

Value

a list containing:

results

simulation results for each value of n

plot1

1st plot of results for each value until max_n

plot2

2nd plot of results for each value until max_n

dev

Examples

species_list <- fish_beginning_with_E
prep <- prepare_invasible(species_list,rho=1, predictors=c("Fake_continuous_trait"))
signal <- invasion_signal(prep)
pred <- predict_invasible(signal)
set.seed(10)
probs <- monitor_species(pred,plot=TRUE,max_n=16)
probs$plot1
probs$plot2


invasible documentation built on Oct. 8, 2026, 5:07 p.m.