View source: R/monitor_species.R
| monitor_species | R Documentation |
Evaluates the probability of :
Detecting at least one invasion within n given species, under ranked monitoring, i.e. the highest-probability n species, vs a random selection.
Given an invasion, detecting it within the n species, under ranked monitoring, i.e. the highest-probability n species, vs a random selection.
monitor_species(pred_out, plot = FALSE, max_n = 25)
pred_out |
Output from |
plot |
Logical. If TRUE, returns ggplot objects. |
max_n |
Integer. Highest n value to be plotted (n=25 as default). |
a list containing:
simulation results for each value of n
1st plot of results for each value until max_n
2nd plot of results for each value until max_n
dev
species_list <- fish_beginning_with_E
prep <- prepare_invasible(species_list,rho=1, predictors=c("Fake_continuous_trait"))
signal <- invasion_signal(prep)
pred <- predict_invasible(signal)
set.seed(10)
probs <- monitor_species(pred,plot=TRUE,max_n=16)
probs$plot1
probs$plot2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.